<?php
/**
 * EAPC export functions
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Eduard Diaz, Scopia visual interface systems SL <edudiaz@scopia.es>
 *
 */

if(!defined('DOKU_INC')) die();
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN . 'admin.php');
require_once(DOKU_PLUGIN . 'htmlexport/namespaces.php');

class admin_plugin_htmlexport extends DokuWiki_Admin_Plugin {
    var $version = '2011-11-12';
    var $output = array();
    var $dir = '';
    var $tmpdir = 'tmp/';
    var $numtpl = 4;
    var $filename = '';
    var $pycli = 'export.py html';

    function admin_plugin_htmlexport(){
        $this->setupLocale();
    }

    function getInfo(){
      return array(
        'author' => 'Eduard Diaz',
        'email'  => 'edudiaz@scopia.es',
        'date'   => $this->version,
        'name'   => 'HTML Export (admin component)',
        'desc'   => 'HTML export in a zip file containing all wiki pages in html format',
        'url'    => 'http://www.scopia.es/',
      );
    }

    function forAdminOnly(){
        return false;
    }

    function getMenuSort() {
      return 800;
    }

    function handle() {
        if (!isset($_REQUEST['namespace']) || !isset($_REQUEST['filename'])){
            return;
        }
        if ($_REQUEST['namespace'] == '') {
            $this->output['error'] = $this->getLang('error_namespace');
            return;
        }
        if ($_REQUEST['filename'] == '') {
            $this->output['error'] = $this->getLang('error_filename');
            return;
        }
        if ($this->nsExists($_REQUEST['namespace'])){
            $this->output['error'] = $this->getLang('error_exists_ns');
            return;
        }

        $filename = $this->tmpdir.escapeshellcmd($_REQUEST['filename'].'.zip');
        $namespace = escapeshellcmd($_REQUEST['namespace']);

        if ( empty($_REQUEST['tpl']) ) $tpl = '2';
        else $tpl = $_REQUEST['tpl'];

        exec('python '.$this->pycli.' '.$filename.' '.$namespace.' '.$tpl.' 2>&1', $this->output['cmd']);

        if ($this->output['cmd']){
            $this->output['error'] = join('<br/>',$this->output['cmd']).'<br/>';
        }else{
            $this->output['ok'] = $this->getLang('export_ok').'<br/><a href="'.$filename.'">'.$_REQUEST['filename'].'.zip »</a>';
            $this->output['cmd'] = null;
        }

        $this->removetmp();
    }

    function html() {
      global $lang;
      global $ID;

      print $this->plugin_locale_xhtml('intro');

      ptln('<h2>'.$this->getLang('last_documents').'</h2>');
      ptln('<div class="level2">');
      $this->lastdocuments();
      ptln('</div>');
      ptln('<h2>'.$this->getLang('title_form').'</h2>');
      ptln('<div class="level2">');
      ptln('<p>'.$this->getLang('desc_form').'</p><br/>');

      if (isset($this->output['warning'])){
        echo '<div class="notify">';
        echo $this->output['warning'];
        echo '</div><br/>';
      }
      if (isset($this->output['error'])){
        echo '<div class="error">';
        echo $this->output['error'];
        echo '</div><br/>';
      }
      if (isset($this->output['ok'])){
        echo '<div class="success">';
        echo $this->output['ok'];
        echo '</div><br/>';
      }
      ptln('<div class="eapc_plugin">');
      $this->_export_html_form();
      ptln('</div>');
      ptln('</div>');
    }

    function _export_html_form(){
      global $lang;
      global $ID;
      global $conf;
      $this->dir = $conf['datadir'];
      $cpanel = wl($ID).(strpos(wl($ID),'?')?'&amp;':'?').'do=admin';
      ?>
      <div class="eapc_form">
      <!-- formulari d'exportació --->
          <form method="post" action="">
                <p><label><?php echo $this->getLang('tpl_model');?>: </label></p>
                <div class="tpl_models">
                    <?php
                        for ($itpl = 1; $itpl <= $this->numtpl; $itpl++){
                            ?>
                            <div class="tpl_item">
                                <img src="<?php echo DOKU_BASE ?>lib/plugins/htmlexport/images/<?php echo 'tpl_'.$itpl ?>.png" alt="<?php echo $this->getLang('tpl_'.$itpl);?>" />
                                <div class="tpl_optionfield">
                                    <input type="radio" id="id_tpl<?php echo $itpl ?>" name="tpl" value="<?php echo $itpl ?>" <?php
                                        if($_REQUEST['tpl']==$itpl){
                                            echo 'checked="checked"';
                                        } else if(empty($_REQUEST['tpl']) && $itpl == 2){
                                            echo 'checked="checked"';
                                        } ?>/>
                                    <label for id="id_tpl<?php echo $itpl ?>"><?php echo $this->getLang('tpl_'.$itpl);?> </label>
                                </div>
                            </div>
                            <?php
                        }
                    ?>
                    <div style="clear:both;height:1px;"></div>
                </div>
                <br/>
                <p>
                    <label for="id_namespace"><?php echo $this->getLang('namespace');?></label>
                    <input type="text" id="id_namespace" name="namespace" value="<?php echo $_REQUEST['namespace'];?>" />
                </p>
                <p><?php echo $this->getLang('desc_namespace'); ?></p>
                <div class="nstree" id="id_nstree"><?php echo _nstree(); ?></div>
                <br/>
                <p>
                    <label for="id_filename"><?php echo $this->getLang('filename_zip');?></label>
                    <input type="text" id="id_filename" name="filename" value="<?php echo $_REQUEST['filename'];?>" />.zip
                </p>
                <p><input type="submit" class="button" value="<?php echo $this->getLang('btn_export');?>" /></p>
                <script type="text/javascript">
                    if (typeof(window.jQuery) !== 'undefined'){
                        tpl_selector();
                        namespaces_navigator(jQuery('#id_nstree'));
                    }
                    function tpl_selector(){
                        if (typeof(window.jQuery) == 'undefined') return;
                        jQuery("div.tpl_item").click(function(e){
                            //e.preventDefault();
                            jQuery("div.tpl_item_checked").attr("class","tpl_item");
                            jQuery(e.target).parents("div.tpl_item").eq(0).attr("class","tpl_item_checked");
                            if (jQuery(e.target).is("input:radio")){
                                jQuery(e.target).attr("checked", "checked");
                            }else{
                                jQuery("div.tpl_item_checked input:radio").attr("checked", "checked");
                            }
                        });
                        jQuery("input[@name='tpl']:checked").parent().parent().attr("class","tpl_item_checked");
                    }
                    function namespaces_navigator(obj){
                        if (typeof(window.jQuery) == 'undefined') return;
                        var icon_show = '<img src="<?php echo DOKU_BASE ?>lib/plugins/htmlexport/images/plus_12.png" alt="+" />';
                        var icon_hide = '<img src="<?php echo DOKU_BASE ?>lib/plugins/htmlexport/images/minus_12.png" alt="-" />';
                        var icon_item = '<img src="<?php echo DOKU_BASE ?>lib/plugins/htmlexport/images/item_12.png" alt="»" />';
                        obj.find('ul').find('ul').hide();
                        obj.find('a').click(function(e){
                                e.preventDefault();
                                jQuery("#id_namespace").attr('value', jQuery(e.target).attr('id'));
                            }).parent().prepend("<span>"+icon_item+"</span> ");
                        obj.find('a ~ ul')
                            .siblings('span')
                            .html(icon_show)
                            .toggle(function(){
                                    var li = jQuery(this).parent();
                                    jQuery(this).html(icon_hide);
                                    li.find("ul:first").slideDown("medium");
                                },function(){
                                    var li = jQuery(this).parent();
                                    jQuery(this).html(icon_show);
                                    li.find("ul:first").slideUp("medium");
                                    return false;
                            }).hover(function(){
                                    var link = jQuery(this).siblings('a');
                                    link.css({'background':'#efefef'});
                                },function(){
                                    var link = jQuery(this).siblings('a');
                                    link.css({'background':'transparent'});
                            }).attr('class','options');
                    }
                </script>
          </form>
      <!-- final formulari d'exportació --->
      </div>
      <p><a href="<?php echo $cpanel ?>">&laquo; <?php echo $this->getLang('back_cpanel');?></a></p>
      <?php
    }

    function nsExists($ns){
        $ns = str_replace(':','/',$ns);
        if (is_dir($this->dir.'/'.$ns)){
            return true;
        }else{
            return false;
        }
    }

    function lastdocuments(){
        ptln('<table class="inline" style="width:98%;margin:0 auto;">');
        ptln('<tr>');
        ptln('<th>'.$this->getLang('filename_zip').'</th><th style="width:20%;">'.$this->getLang('date').'</th>');
        ptln('</tr>');
        $docs_flag = false;
        if(is_dir($this->tmpdir) && is_readable($this->tmpdir)) {
            $dircontent = scandir($this->tmpdir);
            foreach($dircontent as $key => $content) {
                if (is_file($this->tmpdir.'/'.$content)){
                    $lpath = pathinfo($this->tmpdir.'/'.$content);
                    if ($lpath['extension']=='zip'){
                        if (!$docs_flag) $docs_flag = true;
                        $filedate = filemtime($this->tmpdir.'/'.$content);
                        $ts_now = mktime(0, 0, 0, date("m"),date("d"),date("Y"));
                        ptln('<tr>');
                        ptln('<td><a href="'.$this->tmpdir.$content.'">' . $lpath['filename'] . '</a></td>');
                        ptln('<td>' . date ("d/m/Y - H:i:s.", $filedate) . '</td>');
                        ptln('</tr>');
                    }
                }
            }
        }
        if (!$docs_flag) ptln('<tr><td colspan="2">'.$this->getLang('no_docs').'</td></tr>');
        ptln('</table>');
        ptln('<br/>');
    }

    function removetmp(){
        $tmpdir = $this->tmpdir;
        if(is_dir($tmpdir) && is_readable($tmpdir)) {
            $dircontent = scandir($tmpdir);
            foreach($dircontent as $key => $content) {
                if (is_file($tmpdir.'/'.$content)){
                    $lpath = pathinfo($tmpdir.'/'.$content);
                    if ($lpath['extension']=='zip'){
                        $filedate = filemtime($tmpdir.'/'.$content);
                        $ts_now = mktime(0, 0, 0, date("m"),date("d"),date("Y"));
                        if ((round(($ts_now - $filedate) / (60 * 60 * 24))+1) > 2){
                            @unlink($tmpdir.'/'.$content);
                        }
                    }
                }
            }
        }
    }
}
