<?php

/**
 * HTML5VideoPlayer: Allows to embed a HTML5 video into Wiki pages
 *
 * This plugin is based on the VideoJS player http://videojs.com/
 *
 * Syntax:
 *     <video 300 400>
 *     mp4=wiki:prueba.mp4
 *     webm=wiki:prueba.webm
 *     ogv=wiki:prueba.ogv
 *     </video>
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Alexey Markov <redrat@mail.ru>
 * @version    0.1
 */

if(!defined('DOKU_INC')) die();
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
define('FLOWPLAYER', DOKU_BASE.'lib/plugins/flowplayer/player/flowplayer-3.1.5.swf');
require_once(DOKU_PLUGIN.'syntax.php');

class syntax_plugin_htmlexport extends DokuWiki_Syntax_Plugin {
    var $version = '2011-11-12';

    function getInfo() {
        return array(
            'author' => 'Eduard Diaz',
            'email'  => 'edudiaz@scopia.es',
            'date'   => $this->version,
            'name'   => 'HTML5VideoPlayer (syntax plugin)',
            'desc'   => 'Allows to embed a HTML5 video into Wiki pages',
            'url'    => 'http://www.scopia.es'
        );
    }

    function getType() { return 'substition'; }

    function getSort() { return 32; }

    function connectTo($mode) {
        $this->Lexer->addSpecialPattern('<video.*?</video>\n',$mode,'plugin_htmlexport');
    }

    function handle($match, $state, $pos, &$handler){
        $htoolbar = 24;
        //$height = 240 + $htoolbar;
        $height = 240;
        $width = 320;
        $sources = array();
        $video_sources = trim(substr($match, 7, -2));

        // size and sources list
        if(strpos($video_sources, ">")){
            list($video_size, $video_sources) = explode(">", $video_sources, 2);

            // Size
            $size_list = explode(" ", trim($video_size));
            if (count($size_list) > 0){
                if( intval($size_list[0]) > 100 )
                    $width = intval($size_list[0]);
            }
            if (count($size_list) > 1){
                if( intval($size_list[1]) > 100 ){
                    //$height = intval($size_list[1]) + $htoolbar;
                    $height = intval($size_list[1]);
                }
            }
            // Source
            $video_sources = trim($video_sources);
        }

        // Parse Sources
        $sources = $this->get_sources($video_sources);

        return array(
                     'width' => $width,
                     'height' => $height,
                     'sources' => $sources
                     );
    }

    function render($mode, &$renderer, $data) {
        if($mode == 'xhtml'){
            /* DEBUG
            $renderer->doc .= '<p>
                width=  "'.$data['width'].'",<br/>
                height= "'.$data['height'].'",<br/>
                sources= "'.var_export($data['sources'], true).'"
            </p>';
            */
            $renderer->doc .= '<div class="video-js-box box-center">';
            $renderer->doc .= '<video class="video-js"controls="controls" width="'.$data['width'].'" height="'.$data['height'].'">';

            foreach($data['sources'] as $codec => $source){
                switch ($codec) {
                    case 'mp4':
                        $renderer->doc .= '<source src="'.$source.'" type=\'video/mp4; codecs="avc1.42E01E, mp4v.20.8, samr"\'></source>';
                        break;
                    case 'webm':
                        $renderer->doc .= '<source src="'.$source.'" type=\'video/webm; codecs="vp8, vorbis"\'></source>';
                        break;
                    case 'ogv':
                        $renderer->doc .= '<source src="'.$source.'" type=\'video/ogg; codecs="vorbis, theora"\'></source>';
                        break;
                }
            }

            // Flash Fallback. Use any flash video player.
            // Make sure to keep the vjs-flash-fallback class
            $renderer->doc .='
                    <object id="flash_fallback_1" class="vjs-flash-fallback" width="'.$data['width'].'" height="'.$data['height'].'" type="application/x-shockwave-flash" data="http://releases.flowplayer.org/swf/flowplayer-3.2.7.swf">
                        <param name="movie" value="http://releases.flowplayer.org/swf/flowplayer-3.2.7.swf" />
                        <param name="allowfullscreen" value="true" />
                        <param name="flashvars" value=\'config={"clip":{"url": "'.$this->get_host_url().$data['sources']['mp4'].'","autoPlay":false,"autoBuffering":true}}\' />
                    </object>';
            // Fallback if HTML5 video is not supported
            // No video playback capabilities
            $renderer->doc .='<a href="'.$source.'">'.$this->getLang('error_video_html5').'</a>';
            $renderer->doc .='</video>';
            $renderer->doc .='<p class="vjs-no-video"><strong>'.$this->getLang('video_download').'</strong> <a href="'.$data['sources']['mp4'].'">'.$this->getLang('video_link').'</a></p>';
            $renderer->doc .='</div>';
            return true;
        }
        return false;
    }

    function get_host_url(){
        $url_list = parse_url(DOKU_URL);
        return $url_list['scheme'].'://'.$url_list['host'];
    }

    function get_sources($video_sources){
        $src_list = array();
        foreach (preg_split("/[\r\n|\r|\n|,]+/", $video_sources) as $line) {
            if (strlen(trim($line)) == 0) continue;
            list($codec, $source) = explode("=", $line, 2);
            if (trim($source)!="" && in_array(trim($codec), array("mp4", "webm", "ogv"))){
                $source = trim($source);
                $codec = trim($codec);
                if (strpos($source,'://')===false) {
                    $source = ml($source);
                }
                $source = str_replace("%", "%25", $source); // Dirty hack for non-latin filenames
                $src_list[$codec] = $source;
            }
        }
        return $src_list;
    }
}
